@@ -4,49 +4,38 @@
 :mod:`Quantulum` classes.
 """
 
+from typing import Any, Dict, List, Optional, Tuple
+
 from . import speak
 
+
 ###############################################################################
-
-
-class Quantity(object):
+class Entity(object):
     """
-    Class for a quantity (e.g. "4.2 gallons").
+    Class for an entity (e.g. "volume").
     """
 
     def __init__(
         self,
-        value=None,
-        unit=None,
-        surface=None,
-        span=None,
-        uncertainty=None,
-        lang="en_US",
+        name: str,
+        dimensions: List[Dict[str, Any]] = [],
+        uri: Optional[str] = None,
     ):
 
-        self.value = value
-        self.unit = unit
-        self.surface = surface
-        self.span = span
-        self.uncertainty = uncertainty
-        self.lang = lang
+        self.name = name
+        self.dimensions = dimensions
+        self.uri = uri
 
     def __repr__(self):
 
-        msg = 'Quantity(%g, "%s")'
-        msg = msg % (self.value, repr(self.unit))
+        msg = 'Entity(name="%s", uri=%s)'
+        msg = msg % (self.name, self.uri)
         return msg
 
     def __eq__(self, other):
 
         if isinstance(other, self.__class__):
-            return (
-                self.value == other.value
-                and self.unit == other.unit
-                and self.surface == other.surface
-                and self.span == other.span
-                and self.uncertainty == other.uncertainty
-            )
+            return self.name == other.name and self.dimensions == other.dimensions
         else:
             return False
 
@@ -54,15 +43,9 @@ class Quantity(object):
 
         return not self.__eq__(other)
 
-    def __str__(self):
-        return self.to_spoken(self.lang)
+    def __hash__(self):
 
-    def to_spoken(self, lang=None):
-        """
-        Express quantity as a speakable string
-        :return: Speakable version of this quantity
-        """
-        return speak.quantity_to_spoken(self, lang or self.lang)
+        return hash(repr(self))
 
 
 ###############################################################################
@@ -73,14 +56,14 @@ class Unit(object):
 
     def __init__(
         self,
-        name=None,
-        surfaces=None,
-        entity=None,
-        uri=None,
-        symbols=None,
-        dimensions=None,
-        currency_code=None,
-        original_dimensions=None,
+        name: str,
+        entity: Entity,
+        surfaces: List[str] = [],
+        uri: Optional[str] = None,
+        symbols: List[str] = [],
+        dimensions: List[Dict[str, Any]] = [],
+        currency_code: Optional[str] = None,
+        original_dimensions: Optional[List[Dict[str, Any]]] = None,
         lang="en_US",
     ):
         """Initialization method."""
@@ -95,7 +78,7 @@ class Unit(object):
         self.currency_code = currency_code
         self.lang = lang
 
-    def to_spoken(self, count=1, lang=None):
+    def to_spoken(self, count=1, lang=None) -> str:
         """
         Convert a given unit to the unit in words, correctly inflected.
         :param count: The value of the quantity (i.e. 1 for one watt, 2 for
@@ -139,27 +122,46 @@ class Unit(object):
 
 
 ###############################################################################
-class Entity(object):
+
+
+class Quantity(object):
     """
-    Class for an entity (e.g. "volume").
+    Class for a quantity (e.g. "4.2 gallons").
     """
 
-    def __init__(self, name=None, dimensions=None, uri=None):
+    def __init__(
+        self,
+        value: float,
+        unit: Unit,
+        surface: Optional[str] = None,
+        span: Optional[Tuple[int, int]] = None,
+        uncertainty: Optional[float] = None,
+        lang="en_US",
+    ):
 
-        self.name = name
-        self.dimensions = dimensions
-        self.uri = uri
+        self.value = value
+        self.unit = unit
+        self.surface = surface
+        self.span = span
+        self.uncertainty = uncertainty
+        self.lang = lang
 
     def __repr__(self):
 
-        msg = 'Entity(name="%s", uri=%s)'
-        msg = msg % (self.name, self.uri)
+        msg = 'Quantity(%g, "%s")'
+        msg = msg % (self.value, repr(self.unit))
         return msg
 
     def __eq__(self, other):
 
         if isinstance(other, self.__class__):
-            return self.name == other.name and self.dimensions == other.dimensions
+            return (
+                self.value == other.value
+                and self.unit == other.unit
+                and self.surface == other.surface
+                and self.span == other.span
+                and self.uncertainty == other.uncertainty
+            )
         else:
             return False
 
@@ -167,6 +169,12 @@ class Entity(object):
 
         return not self.__eq__(other)
 
-    def __hash__(self):
+    def __str__(self):
+        return self.to_spoken(self.lang)
 
-        return hash(repr(self))
+    def to_spoken(self, lang=None):
+        """
+        Express quantity as a speakable string
+        :return: Speakable version of this quantity
+        """
+        return speak.quantity_to_spoken(self, lang or self.lang)
